summaryrefslogtreecommitdiff
path: root/engine/items/tms.asm
diff options
context:
space:
mode:
Diffstat (limited to 'engine/items/tms.asm')
-rwxr-xr-xengine/items/tms.asm4
1 files changed, 2 insertions, 2 deletions
diff --git a/engine/items/tms.asm b/engine/items/tms.asm
index ef427860..511aab5b 100755
--- a/engine/items/tms.asm
+++ b/engine/items/tms.asm
@@ -1,11 +1,11 @@
; tests if mon [wcf91] can learn move [wd0e0]
CanLearnTM: ; 1373e (4:773e)
ld a, [wcf91]
ld [wd0b5], a
call GetMonHeader
ld hl, W_MONHLEARNSET
push hl
- ld a, [wd0e0]
+ ld a, [wMoveNum]
ld b, a
ld c, $0
ld hl, TechnicalMachines
@@ -1,11 +1,11 @@
-; tests if mon [wcf91] can learn move [wd0e0]
+; tests if mon [wcf91] can learn move [wMoveNum]
CanLearnTM: ; 1373e (4:773e)
ld a, [wcf91]